@@ -115,17 +115,6 @@ def test_table_CellDfn():
         assert(not c.matches(*rc, 10,10))
 
 
-@pytest.mark.xfail(reason="can't reproduce")
-def test_border_hilite_bug():
-    o, p = _printer(ascii=True, color=True)
-    t= Table(0,0,tmpl='grid')
-    t('\by a\tb', '\tc\td\t')
-    p(t)
-    print(o.getvalue())
-    assert(o.getvalue() == '')
-    raise(False)
-
-
 
 def test_sudoku():
     o,p = _printer()
@@ -154,7 +143,7 @@ def test_sudoku():
 def test_table_partial_show():
     ''' Show a portion of the table while building.  The col widths may change, so use fixed col widths
     '''
-    pass
+    print.card('\berr Error:\t', *args, **kwargs)
 
 
 def test_table_coldfns():
